EXPORTS
	??0TWsGraphicAnimation@@QAE@XZ @ 1 NONAME ; TWsGraphicAnimation::TWsGraphicAnimation(void)
	??1CFrame@CWsGraphicBitmapAnimation@@UAE@XZ @ 2 NONAME ; CWsGraphicBitmapAnimation::CFrame::~CFrame(void)
	??1CWsGraphicBitmap@@UAE@XZ @ 3 NONAME ; CWsGraphicBitmap::~CWsGraphicBitmap(void)
	??1CWsGraphicBitmapAnimation@@UAE@XZ @ 4 NONAME ; CWsGraphicBitmapAnimation::~CWsGraphicBitmapAnimation(void)
	??1CWsGraphicTestFrameRate@@UAE@XZ @ 5 NONAME ; CWsGraphicTestFrameRate::~CWsGraphicTestFrameRate(void)
	?Bitmap@CFrame@CWsGraphicBitmapAnimation@@QBEPBVCFbsBitmap@@XZ @ 6 NONAME ; class CFbsBitmap const * CWsGraphicBitmapAnimation::CFrame::Bitmap(void) const
	?FrameInfo@CFrame@CWsGraphicBitmapAnimation@@QBE?AVTFrameInfo@@XZ @ 7 NONAME ; class TFrameInfo CWsGraphicBitmapAnimation::CFrame::FrameInfo(void) const
	?HandleMessage@CWsGraphicBitmap@@EAEXABVTDesC8@@@Z @ 8 NONAME ; void CWsGraphicBitmap::HandleMessage(class TDesC8 const &)
	?IsPaused@TWsGraphicAnimation@@QBEHXZ @ 9 NONAME ; int TWsGraphicAnimation::IsPaused(void) const
	?IsPlaying@TWsGraphicAnimation@@QBEHXZ @ 10 NONAME ; int TWsGraphicAnimation::IsPlaying(void) const
	?IsStopped@TWsGraphicAnimation@@QBEHXZ @ 11 NONAME ; int TWsGraphicAnimation::IsStopped(void) const
	?IsStopping@TWsGraphicAnimation@@QBEHXZ @ 12 NONAME ; int TWsGraphicAnimation::IsStopping(void) const
	?Loops@TWsGraphicAnimation@@QBEHXZ @ 13 NONAME ; int TWsGraphicAnimation::Loops(void) const
	?Mask@CFrame@CWsGraphicBitmapAnimation@@QBEPBVCFbsBitmap@@XZ @ 14 NONAME ; class CFbsBitmap const * CWsGraphicBitmapAnimation::CFrame::Mask(void) const
	?NewL@CFrame@CWsGraphicBitmapAnimation@@SAPAV12@XZ @ 15 NONAME ; class CWsGraphicBitmapAnimation::CFrame * CWsGraphicBitmapAnimation::CFrame::NewL(void)
	?NewL@CWsGraphicBitmap@@SAPAV1@ABVTWsGraphicId@@PBVCFbsBitmap@@1@Z @ 16 NONAME ; class CWsGraphicBitmap * CWsGraphicBitmap::NewL(class TWsGraphicId const &, class CFbsBitmap const *, class CFbsBitmap const *)
	?NewL@CWsGraphicBitmap@@SAPAV1@PBVCFbsBitmap@@0@Z @ 17 NONAME ; class CWsGraphicBitmap * CWsGraphicBitmap::NewL(class CFbsBitmap const *, class CFbsBitmap const *)
	?NewL@CWsGraphicBitmap@@SAPAV1@VTUid@@PBVCFbsBitmap@@1@Z @ 18 NONAME ; class CWsGraphicBitmap * CWsGraphicBitmap::NewL(class TUid, class CFbsBitmap const *, class CFbsBitmap const *)
	?NewL@CWsGraphicBitmapAnimation@@SAPAV1@ABV?$TArray@PAVCFrame@CWsGraphicBitmapAnimation@@@@@Z @ 19 NONAME ; class CWsGraphicBitmapAnimation * CWsGraphicBitmapAnimation::NewL(class TArray<class CWsGraphicBitmapAnimation::CFrame *> const &)
	?NewL@CWsGraphicBitmapAnimation@@SAPAV1@ABVTWsGraphicId@@ABV?$TArray@PAVCFrame@CWsGraphicBitmapAnimation@@@@@Z @ 20 NONAME ; class CWsGraphicBitmapAnimation * CWsGraphicBitmapAnimation::NewL(class TWsGraphicId const &, class TArray<class CWsGraphicBitmapAnimation::CFrame *> const &)
	?NewL@CWsGraphicBitmapAnimation@@SAPAV1@VTUid@@ABV?$TArray@PAVCFrame@CWsGraphicBitmapAnimation@@@@@Z @ 21 NONAME ; class CWsGraphicBitmapAnimation * CWsGraphicBitmapAnimation::NewL(class TUid, class TArray<class CWsGraphicBitmapAnimation::CFrame *> const &)
	?NewL@CWsGraphicTestFrameRate@@SAPAV1@ABVTWsGraphicId@@@Z @ 22 NONAME ; class CWsGraphicTestFrameRate * CWsGraphicTestFrameRate::NewL(class TWsGraphicId const &)
	?NewL@CWsGraphicTestFrameRate@@SAPAV1@VTUid@@@Z @ 23 NONAME ; class CWsGraphicTestFrameRate * CWsGraphicTestFrameRate::NewL(class TUid)
	?NewL@CWsGraphicTestFrameRate@@SAPAV1@XZ @ 24 NONAME ; class CWsGraphicTestFrameRate * CWsGraphicTestFrameRate::NewL(void)
	?OnReplace@CWsGraphicBitmap@@EAEXXZ @ 25 NONAME ; void CWsGraphicBitmap::OnReplace(void)
	?Pause@TWsGraphicAnimation@@QAEXXZ @ 26 NONAME ; void TWsGraphicAnimation::Pause(void)
	?Play@TWsGraphicAnimation@@QAEXH@Z @ 27 NONAME ; void TWsGraphicAnimation::Play(int)
	?SetBitmap@CFrame@CWsGraphicBitmapAnimation@@QAEXPAVCFbsBitmap@@@Z @ 28 NONAME ; void CWsGraphicBitmapAnimation::CFrame::SetBitmap(class CFbsBitmap *)
	?SetFrameInfo@CFrame@CWsGraphicBitmapAnimation@@QAEXABVTFrameInfo@@@Z @ 29 NONAME ; void CWsGraphicBitmapAnimation::CFrame::SetFrameInfo(class TFrameInfo const &)
	?SetMask@CFrame@CWsGraphicBitmapAnimation@@QAEXPAVCFbsBitmap@@@Z @ 30 NONAME ; void CWsGraphicBitmapAnimation::CFrame::SetMask(class CFbsBitmap *)
	?Share@CWsGraphicBitmap@@UAEHVTSecureId@@@Z @ 31 NONAME ; int CWsGraphicBitmap::Share(class TSecureId)
	?Share@CWsGraphicBitmapAnimation@@UAEHVTSecureId@@@Z @ 32 NONAME ; int CWsGraphicBitmapAnimation::Share(class TSecureId)
	?ShareGlobally@CWsGraphicBitmap@@UAEHXZ @ 33 NONAME ; int CWsGraphicBitmap::ShareGlobally(void)
	?ShareGlobally@CWsGraphicBitmapAnimation@@UAEHXZ @ 34 NONAME ; int CWsGraphicBitmapAnimation::ShareGlobally(void)
	?Stop@TWsGraphicAnimation@@QAEXH@Z @ 35 NONAME ; void TWsGraphicAnimation::Stop(int)
	?UnShare@CWsGraphicBitmap@@UAEHVTSecureId@@@Z @ 36 NONAME ; int CWsGraphicBitmap::UnShare(class TSecureId)
	?UnShare@CWsGraphicBitmapAnimation@@UAEHVTSecureId@@@Z @ 37 NONAME ; int CWsGraphicBitmapAnimation::UnShare(class TSecureId)
	?UnShareGlobally@CWsGraphicBitmap@@UAEHXZ @ 38 NONAME ; int CWsGraphicBitmap::UnShareGlobally(void)
	?UnShareGlobally@CWsGraphicBitmapAnimation@@UAEHXZ @ 39 NONAME ; int CWsGraphicBitmapAnimation::UnShareGlobally(void)
	??0TWsGraphicFrameRate@@QAE@XZ @ 40 NONAME ; TWsGraphicFrameRate::TWsGraphicFrameRate(void)

